from django.test import TestCase

# Create your tests here.


class TestFormGenerator(TestCase):


    def test_get_published_forms(self):
        ...

    def test_get_non_published_forms(self):
        ...

    def test_submit_form_successfully(self):
        ...

    def test_submit_form_failed(self):
        ...

    def test_generate_fields(self):
        ...

    def test_pre_api(self):
        ...

    def test_render_pre_api(self):
        ...

    def test_post_api(self):
        ...

    def test_render_post_api(self):
        ...

    def test_edit_form_successfully(self):
        ...

    def test_edit_form_failed(self):
        ...

    def test_show_response(self):
        ...



    